<?php
/**
 * @package Tabaoca.Component.Tabapapo.Administrator
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

namespace Tabaoca\Component\Tabapapo\Administrator\Model;

\defined('_JEXEC') or die;

use stdClass;
use Joomla\CMS\MVC\Model\BaseModel;
use Joomla\CMS\Factory;

/**
 * Model of Tabapapo Chat System component
 *
 * @package     Tabaoca.Component.Tabapapo.Administrator
 * @subpackage  com_tabapapo
 * @since       1.0.0
 */
class DashboardModel extends BaseModel {
	
    /**
	* Method to verify changed data on database.
	* 
	* @return  object  Response Data to XHR call.
	* @since   1.0.0
	*/
	public function run ($n_users_on, $n_users, $n_active_chats, $n_chats, $n_messages) { 

		$trigger = true;

		$data = new stdClass();
		$data->users_on = null;
		$data->users = null;
		$data->chats = null;
		$data->active_chats = null;
		$data->messages = null;

		do { 

			set_time_limit(20);

			$result = $this->data_tabapapo();

			if ($result->users_on != $n_users_on) {

				$data->users_on = $result->users_on;
				$trigger = false;

			}

			if ($result->users != $n_users) {

				$data->users = $result->users;
				$trigger = false;

			}

			if ($result->chats != $n_chats) {

				$data->chats = $result->chats;
				$trigger = false;

			}

			if ($result->active_chats != $n_active_chats) {

				$data->active_chats = $result->active_chats;
				$trigger = false;

			}

			if ($result->messages != $n_messages) {

				$data->messages = $result->messages;
				$trigger = false;

			}

			usleep(40);

		} while ($trigger);

		return $data;

	}

	/**
	* Method to verify number of online users, chats and messages.
	* 
	* @return  object  Response Data to XHR call.
	* @since   1.0.0
	*/
	public function data_tabapapo () {

		$data = new stdClass();

		$db = Factory::getDbo();
		
        $query_a = $db->getQuery(true);

		$query_a->select('id, name, username');
		$query_a->from($db->quoteName('#__users'));

		$db->setQuery($query_a);
		$db->execute();
		$data->users = $db->getNumRows();

		$query_b = $db->getQuery(true);

		$query_b->select($db->quoteName(array('userid','username')));
		$query_b->from($db->quoteName('#__session'));
		$query_b->where('guest = 0 AND client_id = 0');
		
		$db->setQuery($query_b);
		$db->execute();
		$data->users_on = $db->getNumRows();

		$query_c = $db->getQuery(true);

		$query_c->select($db->quoteName(array('id')));
		$query_c->from($db->quoteName('#__tabapapo_msg'));
        $query_c->where('usu_id != 0');

		$db->setQuery($query_c);
		$db->execute();
		$data->messages = $db->getNumRows();

		$query_d = $db->getQuery(true);

		$query_d->select($db->quoteName(array('id')));
		$query_d->from($db->quoteName('#__tabapapo_usu'));
		$query_d->group($db->quoteName('sala_id'));

		$db->setQuery($query_d);
		$db->execute();
		$data->active_chats = $db->getNumRows();

		$query_e = $db->getQuery(true);

		$query_e->select($db->quoteName(array('id')));
		$query_e->from($db->quoteName('#__tabapapo'));
		$query_e->where('published = 1');

		$db->setQuery($query_e);
		$db->execute();
		$data->chats = $db->getNumRows();

		return $data;

	}

}
