<?php
/**
 * @package Tabaoca.Component.Tabapapo.Administrator
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

namespace Tabaoca\Component\Tabapapo\Administrator\Model;

\defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\MVC\Model\AdminModel;
use Joomla\CMS\Versioning\VersionableModelTrait;
use Joomla\Database\ParameterType;
use Joomla\Utilities\ArrayHelper;
use Joomla\CMS\Helper\TagsHelper;

class TabapapoModel extends AdminModel
{
	use VersionableModelTrait;
	
	protected $text_prefix = 'COM_TABAPAPO_TABAPAPO';
	
	public $typeAlias = 'com_tabapapo.tabapapo';

	protected $batch_copymove = 'category_id';

	protected $batch_commands = [
		'assetgroup_id' => 'batchAccess',
		'language_id'   => 'batchLanguage',
		'tag'           => 'batchTag',
		'user_id'       => 'batchUser',
	];

	public function getForm($data = [], $loadData = true)
	{
		// Get the form.
		$form = $this->loadForm($this->typeAlias, 'tabapapo', ['control' => 'jform', 'load_data' => $loadData]);

		if (empty($form)) {
			return false;
		}

		return $form;
	}

	protected function loadFormData()
	{
		$app = Factory::getApplication();

		// Check the session for previously entered form data.
		$data = $app->getUserState('com_tabapapo.edit.tabapapo.data', []);

		if (empty($data)) {
			$data = $this->getItem();

			// Prime some default values.
			if ($this->getState('tabapapo.id') == 0) {
				$data->set('catid', $app->input->get('catid', $app->getUserState('com_tabapapo.tabapapos.filter.category_id'), 'int'));
			}
		}

		$this->preprocessData($this->typeAlias, $data);

		return $data;
	}

	public function getItem($pk = null)
	{
		$item = parent::getItem($pk);

		// Load item tags
		if (!empty($item->id)) {
			$item->tags = new TagsHelper;
			$item->tags->getTagIds($item->id, 'com_tabapapo.tabapapo');
		}

		return $item;
	}

	public function featured($pks, $value = 0)
	{
		// Sanitize the ids.
		$pks = ArrayHelper::toInteger((array) $pks);

		if (empty($pks)) {
			$this->setError(Text::_('COM_TABAPAPO_NO_ITEM_SELECTED'));

			return false;
		}

		$table = $this->getTable();

		try {
			$db = $this->getDbo();

			$query = $db->getQuery(true);
			$query->update($db->quoteName('#__tabapapo'));
			$query->set($db->quoteName('featured') . ' = :featured');
			$query->whereIn($db->quoteName('id'), $pks);
			$query->bind(':featured', $value, ParameterType::INTEGER);

			$db->setQuery($query);

			$db->execute();
		} catch (\Exception $e) {
			$this->setError($e->getMessage());

			return false;
		}

		$table->reorder();

		// Clean component's cache
		$this->cleanCache();

		return true;
	}

	protected function preprocessForm(\JForm $form, $data, $group = 'content')
	{
		parent::preprocessForm($form, $data, $group);
	}

	protected function prepareTable($table)
	{
		$table->generateAlias();
	}
}
