<?php
/**
 * @package Tabaoca.Component.Tabapapo.Administrator
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

namespace Tabaoca\Component\Tabapapo\Administrator\View\Dashboard;

\defined('_JEXEC') or die;

use Joomla\CMS\Language\Text;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\Helper\ContentHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

class HtmlView extends BaseHtmlView
{
	/**
	 * Display the Tabapapo Chat view
	 *
	 * @param   string  $tpl  The name of the template file to parse; automatically searches through the template paths.
	 *
	 * @return  void
	 */
	public function display($tpl = null): void
	{
		$this->canDo = ContentHelper::getActions('com_tabapapo');

        // Set the toolbar
		$this->addToolBar();

		// Set the document
		$this->setDocument(null);

		// Display the template
		parent::display($tpl);

	}

    protected function addToolbar()
	{

        $user  = $this->getCurrentUser();
        $toolbar = Toolbar::getInstance('toolbar');

        ToolbarHelper::title(Text::_('COM_TABAPAPO_MANAGER_DASHBOARD'), 'comments-2 tabapapo');

        if ($user->authorise('core.admin', 'com_tabapapo') || $user->authorise('core.options', 'com_tabapapo')) {
            ToolbarHelper::preferences('com_tabapapo');
        }

        ToolbarHelper::help('Tabapapo');

    }

    /**
	 * Method to set up the document properties
	 *
	 * @return void
	 */
	public function setDocument($doc): void {

		$document = Factory::getDocument();
		$document->setTitle(Text::_('COM_TABAPAPO_ADMINISTRATION'));

		$document->addScript(Uri::root() . 'media/com_tabapapo/js/tabapapo_admin.js');
		$document->addStyleSheet(Uri::root() . 'media/com_tabapapo/css/tabapapo_admin.css');

	}

}
