<?php
/**
 * @package Tabaoca.Component.Tabapapo.Administrator
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

namespace Tabaoca\Component\Tabapapo\Administrator\View\Tabapapos;

\defined('_JEXEC') or die;

use Joomla\CMS\Helper\ContentHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Language\Multilanguage;
use Joomla\CMS\MVC\View\HtmlView as BaseHtmlView;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\Factory;
use Joomla\CMS\MVC\View\GenericDataException;

class HtmlView extends BaseHtmlView
{
	protected $items;

	protected $categories = [];
	
	protected $pagination;

	protected $state;

	public $filterForm;

	public $activeFilters = [];

	private $isEmptyState = false;

	
	public function display($tpl = null): void
	{

        $model               = $this->getModel();
        //$this->categories    = $model->getCategoryOrders();
        $this->items         = $model->getItems();
        $this->pagination    = $model->getPagination();
        $this->state         = $model->getState();
        $this->filterForm    = $model->getFilterForm();
        $this->activeFilters = $model->getActiveFilters();
        
        /*$this->state = $this->get('State');
        $this->items = $this->get('Items');
        $this->pagination = $this->get('Pagination');
        $this->filterForm = $this->get('FilterForm');
        $this->activeFilters = $this->get('ActiveFilters');*/

        // Check for errors.
        if (count($errors = $this->get('Errors'))) {
            throw new GenericDataException(implode("\n", $errors), 500);
        }

        if (!\count($this->items) && $this->isEmptyState = $this->get('IsEmptyState')) {
            $this->setLayout('emptystate');
        }

        if (!count($this->items) && $this->get('IsEmptyState')) {
            $this->setLayout('emptystate');
        }

        $this->addToolbar();

        // We do not need to filter by language when multilingual is disabled
        if (!Multilanguage::isEnabled()) {
            unset($this->activeFilters['language']);
            $this->filterForm->removeField('language', 'filter');
        }

		parent::display($tpl);

	}

	protected function addToolbar()
	{

		$canDo = ContentHelper::getActions('com_tabapapo', 'category', $this->state->get('filter.category_id'));
		$user  = $this->getCurrentUser();

		// Get the toolbar object instance
		$toolbar = Toolbar::getInstance('toolbar');

		ToolbarHelper::title(Text::_('COM_TABAPAPO_MANAGER_TABAPAPO'), 'comments-2 tabapapo');

		if ($canDo->get('core.create') || \count($user->getAuthorisedCategories('com_tabapapo', 'core.create')) > 0) {
			$toolbar->addNew('tabapapo.add');
		}

		if (!$this->isEmptyState && ($canDo->get('core.edit.state') || ($this->state->get('filter.published') == -2 && $canDo->get('core.delete')))) {
            $dropdown = $toolbar->dropdownButton('status-group', 'JTOOLBAR_CHANGE_STATUS')
                ->toggleSplit(false)
                ->icon('icon-ellipsis-h')
                ->buttonClass('btn btn-action')
                ->listCheck(true);

            $childBar = $dropdown->getChildToolbar();

			if ($canDo->get('core.edit.state')) {
                if ($this->state->get('filter.published') != 2) {
                    $childBar->publish('tabapapos.publish')->listCheck(true);

                    $childBar->unpublish('tabapapos.unpublish')->listCheck(true);
                }

                if ($this->state->get('filter.published') != -1) {
                    if ($this->state->get('filter.published') != 2) {
                        $childBar->archive('tabapapos.archive')->listCheck(true);
                    } elseif ($this->state->get('filter.published') == 2) {
                        $childBar->publish('publish')->task('tabapapos.publish')->listCheck(true);
                    }
                }

                $childBar->checkin('tabapapos.checkin');

                if ($this->state->get('filter.published') != -2) {
                    $childBar->trash('tabapapos.trash')->listCheck(true);
                }
            }

			if ($this->state->get('filter.published') == -2 && $canDo->get('core.delete')) {
                $toolbar->delete('tabapapos.delete', 'JTOOLBAR_EMPTY_TRASH')
                    ->message('JGLOBAL_CONFIRM_DELETE')
                    ->listCheck(true);
            }

            // Add a batch button
            if (
                $user->authorise('core.create', 'com_tabapapo')
                && $user->authorise('core.edit', 'com_tabapapo')
                && $user->authorise('core.edit.state', 'com_tabapapo')
            ) {
                $childBar->popupButton('batch', 'JTOOLBAR_BATCH')
                    ->selector('collapseModal')
                    ->listCheck(true);
            }
        }

        if ($user->authorise('core.admin', 'com_tabapapo') || $user->authorise('core.options', 'com_tabapapo')) {
            ToolbarHelper::preferences('com_tabapapo');
        }

        ToolbarHelper::help('Tabapapo');
	}


}
