<?php
/**
 * @package Tabaoca.Component.Tabapapo.Site
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

namespace Tabaoca\Component\Tabapapo\Site\Controller;

\defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\MVC\Controller\FormController;
use Joomla\CMS\Factory;
use Joomla\CMS\Uri\Uri;

class TabapapoController extends FormController {

	protected $view_list = 'tabapapos';
	
	/**
	 * The URL edit variable.
	 *
	 * @var    string
	 * @since  3.2
	 */
	protected $urlVar = 'a.id';

	/**
	* Implement to allowAdd or not
	*
	* Not used at this time (but you can look at how other components use it....)
	* Overwrites: JControllerForm::allowAdd
	*
	* @param array $data
	* @return bool
	*/
	protected function allowAdd($data = array())
	{
		return parent::allowAdd($data);
	}
	/**
	* Implement to allow edit or not
	* Overwrites: JControllerForm::allowEdit
	*
	* @param array $data
	* @param string $key
	* @return bool
	*/
	protected function allowEdit($data = array(), $key = 'id')
	{
		$id = isset( $data[ $key ] ) ? $data[ $key ] : 0;
		if( !empty( $id ) )
		{
			return Factory::getUser()->authorise( "core.edit", "com_tabapapo.tabapapo." . $id );
		}
	}

	/**
     * Method to cancel an edit.
     *
     * @param   string  $key  The name of the primary key of the URL variable.
     *
     * @return  boolean  True if access level checks pass, false otherwise.
     *
     * @since   1.6
     */
    public function cancel($key = 't_id')
    {
        $return = parent::cancel($key);
        // Redirect to the return page.
        $this->setRedirect(Uri::root() . 'index.php?option=com_tabapapo&view=tabapapos');
        return $return;
    }


	/**
     * Method to save a record.
     *
     * @param   string  $key     The name of the primary key of the URL variable.
     * @param   string  $urlVar  The name of the URL variable if different from the primary key (sometimes required to avoid router collisions).
     *
     * @return  boolean  True if successful, false otherwise.
     *
     * @since   1.6
     */
    public function save($key = null, $urlVar = 't_id')
    {
        // Get the application
        $app = $this->app;
        // Get the data from POST
        $data = $this->input->post->get('jform', [], 'array');
        // Save the data in the session.
        $app->setUserState('com_tabapapo.edit.tabapapo.data', $data);
        $result = parent::save($key, $urlVar);
        // If ok, redirect to the return page.
        if ($result) {
            // Flush the data from the session
            $app->setUserState('com_tabapapo.edit.tabapapo.data', null);
            $this->setRedirect(Uri::root() . 'index.php?option=com_tabapapo&view=tabapapos');
        }

        return $result;
    }

}
