<?php
/**
 * @package Tabaoca.Component.Tabapapo.Site
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

namespace Tabaoca\Component\Tabapapo\Site\Model;

\defined('_JEXEC') or die('Restricted access');

use stdClass;
use Joomla\CMS\MVC\Model\FormModel;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Session\Session;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Application\CMSWebApplicationInterface;
use Joomla\Registry\Registry;
use Joomla\CMS\Component\ComponentHelper;

class TabapaposModel extends FormModel {

	
	public function run($sala_id, $n_users_chat, $n_users_on, $room_lmsg_id) {
	   
		$trigger = true;
		
		$data = new stdClass();
		

		do {

			set_time_limit(20);

			$data = $this->loadRoom($sala_id, $room_lmsg_id);
			
			if ($data->n_users != $n_users_chat) {

				$trigger = false;

			}

			if ($data->n_users_on != $n_users_on) {

				$trigger = false;

			}

			if ($data->n_msgs > 0) {

				$trigger = false;

			}

			usleep(50);

		} while ($trigger);

		return $data;

	}


	public function enterRoom($sala_id, $n_users_chat, $n_users_on, $room_lmsg_id) {

		$currentuser = Factory::getuser();

		$usu_id = $currentuser->get("id");
		$usu_name = $currentuser->get("username");
		
		$delusers = $this->deleteUsers($sala_id,'no-msg');

		$db = Factory::getDbo();

		$query = $db->getQuery(true);

		$query->select($db->quoteName(array('id','usu_id')));
		$query->from($db->quoteName('#__tabapapo_usu'));
		$query->where($db->quoteName('usu_id').'='.$db->quote($usu_id));
		$query->where($db->quoteName('sala_id').'='.$db->quote($sala_id));

		$db->setQuery($query);
		$db->execute();
		$num_rows = $db->getNumRows();
		$results = $db->loadObjectlist();
		
		if (!$num_rows) {

			$this->insert_user($sala_id);

		}
		
		$data = new stdClass();

		$data = $this->loadRoom($sala_id, $room_lmsg_id);

		return $data;		  
   
	}	
	
	
	public function loadRoom($sala_id, $room_lmsg_id) {
	   
		$currentuser = Factory::getuser();
			
		$db = Factory::getDbo();
		
		$delmsgs = $this->deleteMsgs($sala_id);
	
		$query_msg = $db->getQuery(true);

		$query_msg->select($db->quoteName(array('a.id','sala_id','usu_id','reservado','msg','falacom_id','params','tempo')));
		$query_msg->from($db->quoteName('#__tabapapo_msg', 'a'));
		$query_msg->where($db->quoteName('a.sala_id').'='.$db->quote($sala_id));
		$query_msg->where($db->quoteName('a.id').'>'.$db->quote($room_lmsg_id));
		
		//Community Buider Integration		
	
		$app = Factory::getApplication();

		$config = $app->getParams('com_tabapapo');
		$cb_integration = $config->get('cb_integration');
		
		if ($cb_integration && ComponentHelper::isEnabled('com_comprofiler')) {

			$query_msg->select ('IF (cb.avatarapproved, cb.avatar, "") as avatar')
			->join('LEFT', $db->quoteName('#__comprofiler', 'cb') . ' ON cb.id = a.usu_id');
			$query_msg->select ('IF (cbt.avatarapproved, cbt.avatar, "") as avatar_talkto')
			->join('LEFT', $db->quoteName('#__comprofiler', 'cbt') . ' ON cbt.id = a.falacom_id');
		
		} else {
		
			$query_msg->select ('"" as avatar');
			$query_msg->select ('"" as avatar_talkto');
		
		}
		
		$query_msg->order($db->quoteName('id'), 'ASC');
		
		$db->setQuery($query_msg);
		$db->execute();
		$num_rows = $db->getNumRows();
		$msgs = $db->loadObjectList();
		
		if ($num_rows > 0) {
			
			for ($i = 0; $i < $num_rows; $i++) {
			
			$msgs[$i]->msg = $this->decrypt_message($msgs[$i]->msg, $msgs[$i]->sala_id);
			
			}
		
		}
		
		$id = $this->updateTime($currentuser->get("id"), $sala_id);

		$delusers = $this->deleteUsers($sala_id, 'yes-msg');
		
		$query_users = $db->getQuery(true);

		$query_users->select($db->quoteName(array('id','sala_id','usu_id','status','ip','params','tempo')));
		$query_users->from($db->quoteName('#__tabapapo_usu'));
		$query_users->where($db->quoteName('sala_id').'='.$db->quote($sala_id));
		$query_users->order($db->quoteName('tempo'), 'ASC');
		
		$db->setQuery($query_users);
		$db->execute();
		$num_users = $db->getNumRows();
		$users = $db->loadObjectList();
		
		$j = 0;

		if ($num_users) {
		
			for ($i = 0; $i < $num_users; $i++) {
				
				if ($users[$i]->status == 1 && $users[$i]->usu_id != $currentuser->get("id")) {

					$j++;

				}

			}
		
		}
		
		$data = new stdClass();
		$data->n_users = $num_users;
		$data->n_users_on = $j;
		$data->users = $users;
		$data->n_msgs = $num_rows;
		$data->msgs = $msgs;

		return $data;
		
	}


	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 *
	 * @see     JController
	 * @since   1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				'id', 'a.id',
				'title', 'a.title',
				'alias', 'a.alias',
				'checked_out', 'a.checked_out',
				'checked_out_time', 'a.checked_out_time',
				'catid', 'a.catid', 'category_id', 'category_title',
				'access', 'a.access', 'access_level',
				'created', 'a.created',
				'created_by', 'a.created_by',
				'ordering', 'a.ordering',
				'featured', 'a.featured',
				'language', 'a.language', 'language_title',
				'publish_up', 'a.publish_up',
				'publish_down', 'a.publish_down',
				'published', 'a.published',
				'hits', 'a.hits',
				'tag',
				'level', 'c.level',
			);
		}

		parent::__construct($config);
	}

	/**
	 * Method to build an SQL query to load the list data.
	 *
	 * @return      string  An SQL query
	 */


	public function getListTaba($my_filter, $filter, $search, $direction)
	{
		$currentuser = Factory::getuser();
		$usu_id = $currentuser->get("id");

		// Initialize variables.
		$db    = Factory::getDbo();
		$query = $db->getQuery(true);

		// Create the base select statement.
		$query->select('a.id as id, a.title as title, a.alias as alias, a.published as published, a.created as created, a.hits as hits, a.params as params')
			  ->from($db->quoteName('#__tabapapo', 'a'))
			  ->group('a.id');

		// Join over the users on.
		$query->select('count(o.sala_id) as users_on')
			->join('LEFT', $db->quoteName('#__tabapapo_usu', 'o') . ' ON o.sala_id = a.id');

		// Join over the categories.
		$query->select($db->quoteName('c.title', 'category_title'))
			->join('LEFT', $db->quoteName('#__categories', 'c') . ' ON c.id = a.catid');

		// Join with users table to get the username of the author
		$query->select($db->quoteName('u.username', 'created_by'))
			->join('LEFT', $db->quoteName('#__users', 'u') . ' ON u.id = a.created_by');


		//Community Buider Integration		
		
		$app = Factory::getApplication();

		$config = $app->getParams('com_tabapapo');
		$cb_integration = $config->get('cb_integration');
		
		if ($cb_integration && ComponentHelper::isEnabled('com_comprofiler')) {

			$query->select ('IF (cb.avatarapproved, cb.avatar, "") as avatar')
			->join('LEFT', $db->quoteName('#__comprofiler', 'cb') . ' ON cb.id = a.created_by');
		
		} else {
		
			$query->select ('"" as avatar');
		
		}
		
		// Filter: like / search
		//$search = $this->getState('filter.search');

		if (!empty($search))
		{
			$like = $db->quote('%' . $search . '%');
			$query->where('a.title LIKE ' . $like);
		}

		if ($my_filter == 1) {

			$query->where('a.created_by = ' . $db->quote($usu_id));
			$query->where('(a.published IN (0, 1))');
		
		} else {

			$query->where('a.published = 1');

		}

		
		
		/* Filter by published state
		$published = $this->getState('filter.published');

		if (is_numeric($published))
		{
			$query->where('a.published = ' . (int) $published);
		}
		elseif ($published === '')
		{
			$query->where('(a.published IN (0, 1))');
		}*/

		// Add the list ordering clause.
		//$orderCol	= $this->state->get('list.ordering', 'title');
		//$orderDirn 	= $this->state->get('list.direction', 'asc');

		if ($direction == 0) {$directionb = 'asc';}
		elseif ($direction == 1) {$directionb = 'desc';}
		
		if ($filter == 2) {
			
			$orderb = '';
			
		} else {
			
			$orderb = ', 2 asc';
			
		}
		
		$order = $filter.' '.$directionb.$orderb;
		
		$query->order($order);

		return $query;
	}
	

	protected $item;
	protected $options;
	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @return	void
	 * @since	2.5
	 */
	
	protected function populateState($ordering = null, $direction = null)
	{
		// Get the message id
		$jinput = Factory::getApplication()->input;
		$id     = $jinput->get('id', 1, 'INT');
		$this->setState('chatroom.id', $id);

		// Load the parameters.
		$this->setState('params', Factory::getApplication()->getParams());
		parent::populateState();
	}
	
	public function getItem()
	{
		if (!isset($this->item)) 
		{
			$id    = $this->getState('chatroom.id');
			$db    = Factory::getDbo();
			$query = $db->getQuery(true);
			$query->select('h.id, h.title, h.created, h.created_by, h.params, c.title as category,
                         h.alias, h.catid, h.description, h.asset_id, h.published, h.params, count(o.sala_id) as users_on')
				  ->from('#__tabapapo as h')
				  ->leftJoin('#__tabapapo_usu as o ON h.id=o.sala_id')
				  ->leftJoin('#__categories as c ON h.catid=c.id')
				  ->where('h.id=' . (int)$id);
			$db->setQuery((string)$query);
		
			if ($this->item = $db->loadObject()) 
			{
				// Load the JSON string
				$params = new Registry;
				$params->loadString($this->item->params, 'JSON');
				$this->item->params = $params;

				// Merge global params with item params
				$params = clone $this->getState('params');
				$params->merge($this->item->params);
				$this->item->params = $params;
				
			}
		}
		return $this->item;
	}
	
	public function getForm($data = array(), $loadData = true)
	{
		$form = $this->loadForm(
			'com_tabapapo.tabapapos',  // just a unique name to identify the form
			'tabapapo',				// the filename of the XML form definition
										// Joomla will look in the models/forms folder for this file
			array(
				'control' => 'jform',	// the name of the array for the POST parameters
				'load_data' => $loadData	// will be TRUE
			)
		);

		if (empty($form))
		{
            $errors = $this->getErrors();
			throw new Exception(implode("\n", $errors), 500);
		}

		return $form;
	}
    
    
    public function getOptions () {
      
		$currentuser = Factory::getuser();
		$usu_id = $currentuser->get("id");
      //$sala_id = $form['sala_id'];
      
		$db = Factory::getDbo();

		$query = $db->getQuery(true);

		$query->select($db->quoteName(array('id', 'title', 'catid', 'created_by')));
		$query->from($db->quoteName('#__tabapapo'));
		//$query->where($db->quoteName('usu_id').'='.$db->quote($usu_id));
		//$query->where($db->quoteName('sala_id').'='.$db->quote($sala_id));

		$db->setQuery($query);
      //$db->execute();
      //$num_rows = $db->getNumRows();
		$this->options = $db->loadObjectlist();
		
      return $this->options;
      
    }

    
	public function runList($page_actual, $my_filter, $list_limit, $filter, $search, $direction, $n_total_rooms, $rooms) {
	   
		$trigger = true;

		$rooms = json_decode($rooms);
		$rooms = json_encode($rooms);

		$data = array();
		
		do {

			set_time_limit(20);

			/*$session = Factory::getSession();

			$search = $session->get('search');*/
			
			$data = $this->listRooms($page_actual, $my_filter, $list_limit, $filter, $search, $direction);
			
			if ($data->n_total_rooms != $n_total_rooms) {

				$trigger = false;

			}

			$d_rooms = json_encode($data->rooms);
			$bool = ($d_rooms === $rooms);
			
			if (!$bool) {

				$trigger = false;

			}

			usleep(50);

		} while ($trigger);

		return $data;

	}


    public function listRooms ($page_actual, $my_filter, $list_limit, $filter, $search, $direction) {
		
		$currentuser = Factory::getuser();
		$usu_id = $currentuser->get("id");
			
		$delusers = $this->deleteUsers(null, 'no-msg');

		$start_limit = ($page_actual * $list_limit) - $list_limit;

		$db = Factory::getDbo();

		$query = $db->getQuery(true);

		$db->setQuery($this->getListTaba($my_filter, $filter, $search, $direction));
		$db->execute();

		$data = new stdClass();
		$data->n_total_rooms = $db->getNumRows();

		$db->setQuery($this->getListTaba($my_filter, $filter, $search, $direction), $start_limit, $list_limit);
		$db->execute();

		$data->rooms = $db->loadObjectlist();

		return $data;
	}


	public function messageSend($form) {

		$currentuser = Factory::getuser();
		$usu_id = $currentuser->get("id");
		$sala_id = $form['sala_id'];
		$talkto_id = $form['talkto_id'];

		$data = new stdClass();
		$data->error = '';

		$db = Factory::getDbo();

		$query = $db->getQuery(true);

		$query->select($db->quoteName(array('id','usu_id')));
		$query->from($db->quoteName('#__tabapapo_usu'));
		$query->where($db->quoteName('usu_id').'='.$db->quote($usu_id));
		$query->where($db->quoteName('sala_id').'='.$db->quote($sala_id));

		$db->setQuery($query);
		$db->execute();
		$num_user = $db->getNumRows();
		$results = $db->loadObjectlist();

		if (!$num_user) {
      
			$this->insert_user($sala_id);
         
		}
		
		if ($talkto_id != 0) {
		
			$db = Factory::getDbo();

			$queryusu = $db->getQuery(true);

			$queryusu->select($db->quoteName(array('id','usu_id')));
			$queryusu->from($db->quoteName('#__tabapapo_usu'));
			$queryusu->where($db->quoteName('usu_id').'='.$db->quote($talkto_id));
			$queryusu->where($db->quoteName('sala_id').'='.$db->quote($sala_id));

			$db->setQuery($queryusu);
			$db->execute();
			$num_rows = $db->getNumRows();
			$results = $db->loadObjectlist();		
			
			if (!$num_rows) {
				
				$data->error = Text::_('COM_TABAPAPO_USEROFF');
				return $data;
			 
			}

		}		

		$params = new stdClass();
		$params->usu_name = $currentuser->get("username");
		$params->talkto_name = $form['talkto_name'];
		$params = json_encode($params);
      
		$mensagem = str_replace("<", "&lt", $form['msg']);
		$mensagem = str_replace(">", "&gt", $mensagem);
      
		if (trim($mensagem) == '') {

			$data->error = 'Void';
         
			return $data;
		
		} else {
         
			$mensagem = $this->encrypt_message($mensagem, $form['sala_id']);

            $msgchat = new stdClass();
   			
   			$msgchat->sala_id = $form['sala_id'];
   			$msgchat->usu_id = $currentuser->get("id");
   			$msgchat->params = $params;
   			$msgchat->msg = $mensagem;
   			$msgchat->falacom_id = $form['talkto_id'];
   			$msgchat->tempo = date('Y-m-d H:i:s');

			if (isset($form['privado'])) {

				$msgchat->reservado = 1;

			} else {

				$msgchat->reservado = 0;

			}

   			Factory::getDbo()->insertObject('#__tabapapo_msg', $msgchat);

      	}

		return $data;

	}

	public function sendMessageSys($form, $type)	{

		$currentuser = Factory::getuser();

		$db = Factory::getDbo();

		$querynow = $db->getQuery(true);
		$querynow->select('now() as now');
		$db->setQuery($querynow);
		$resultnow = $db->loadObjectList();

		$params = new stdClass();
		$params->usu_name = '>';
		$params->talkto_name = $currentuser->get('username');
		$params = json_encode($params);
		
		$params_usu = json_decode($form->params);
      
		try {
		           
			$msgchat = new stdClass();

			if ($type == 1) {$msgchat->msg = $params_usu->usu_name . ' entered.';}

			if ($type == 2) {$msgchat->msg = $params_usu->usu_name . ' left.';}

			if ($type == 3) {$msgchat->msg = $form->msg;}

			$msgchat->msg = $this->encrypt_message($msgchat->msg, $form->sala_id);

			$msgchat->reservado = 0;
			$msgchat->sala_id = $form->sala_id;
			$msgchat->usu_id = 0; //System Id
			$msgchat->params = $params;
			$msgchat->falacom_id = 0;
			$msgchat->tempo = $resultnow[0]->now;

			$resultmsg = Factory::getDbo()->insertObject('#__tabapapo_msg', $msgchat);
         
		}
		catch (Exception $e)
		{
			$msg = $e->getMessage();
			Factory::getApplication()->enqueueMessage($msg, 'error'); 
			$resultmsg = null;
		}

		return $resultmsg; 
	}

	
	public function encrypt_message ($message, $key) {
		
		$algoritmo = "AES-256-CTR";
		$key = $key."-salak";
		$iv = "ZZqZswppWgNrNQmt";
		$tag = "";
		$tag_length = 16;

		$message = openssl_encrypt($message, $algoritmo, $key, OPENSSL_RAW_DATA, $iv, $tag, "", $tag_length);
		$message = base64_encode($message);
		
		return $message;
		
	}
	
	
	public function decrypt_message ($message, $key) {
		
		$algoritimo = "AES-256-CTR";
		$key = $key."-salak";
		$iv = "ZZqZswppWgNrNQmt";

		$message = openssl_decrypt(base64_decode($message), $algoritimo, $key, OPENSSL_RAW_DATA, $iv);
		
		return $message;
		
	}
	

	public function statusUser($sala_id, $status) {

		$currentuser = Factory::getuser();
		$usu_id = $currentuser->get("id");
      
		$db = Factory::getDbo();
		$id = $this->selectId($usu_id, $sala_id);

		$object = new stdClass();
		$object->id = $id[0]->id;
		$object->status = $status;

		$result = $db->updateObject('#__tabapapo_usu', $object, 'id');
		
		return true;

   }


   public function diceroll($sala_id, $dice) {

      $currentuser = Factory::getuser();
      
      if($currentuser->get("id") > 0) {
         
   		try {
      

            $object = new stdClass();
            $object->sala_id = $sala_id;
            $object->dice = $dice;
            $object->msg = $currentuser->get("username").' roll D' . $dice . ': ' . '<b>[ ' . rand(1, $dice). ' ]</b>';

            $this->sendMessageSys($object, 3);
            
            return true;
         }
           
   		catch (Exception $e)
   		{
   			$msg = $e->getMessage();
   			Factory::getApplication()->enqueueMessage($msg, 'error'); 
   			$resultmsg = null;
   		  }
           
      	}
   		else {
   			header('Location:index.php');
   		}

   }


	public function insert_user($sala_id) {

      $currentuser = Factory::getuser();

      if ($currentuser->get("id") > 0) {
      
		try {  

			$usu_id = $currentuser->get("id");
			$usu_name = $currentuser->get("username");

			$db = Factory::getDbo();
			$querynow = $db->getQuery(true);
			$querynow->select('now() as now');
			$db->setQuery($querynow);
			$result = $db->loadObjectList();

			//Community Buider Integration		
		
			$app = Factory::getApplication();

			$config = $app->getParams('com_tabapapo');
			$cb_integration = $config->get('cb_integration');
			
			if ($cb_integration && ComponentHelper::isEnabled('com_comprofiler')) {

				$db    = Factory::getDbo();
				$querya = $db->getQuery(true);
				$querya->select ('IF (cb.avatarapproved, cb.avatar, "") as avatar');
				$querya->from($db->quoteName('#__comprofiler', 'cb'));
				$querya->where($db->quoteName('cb.id').'='.$usu_id);
				$db->setQuery($querya);
				$resulta = $db->loadObjectList();
				$avatar = $resulta[0]->avatar;

			} else {
			
				$avatar = '';
			
			}

			$params = new stdClass();
			$params->usu_name = $currentuser->get("username");
			$params->avatar = $avatar;
			$params->getin_time = $result[0]->now;
			$params = json_encode($params);

			$usuchat = new stdClass();
			$usuchat->sala_id = $sala_id;
			$usuchat->usu_id = $usu_id;
			$usuchat->status = 1;
			$usuchat->params = $params;
			$usuchat->ip = $_SERVER["REMOTE_ADDR"];
			$usuchat->tempo = $result[0]->now;

			$resultusu = Factory::getDbo()->insertObject('#__tabapapo_usu', $usuchat);

			$this->sendMessageSys($usuchat,1);

			return true;

		}

		catch (Exception $e)
		{
			$msg = $e->getMessage();
			Factory::getApplication()->enqueueMessage($msg, 'error'); 
			$resultmsg = null;
		}
        
   	}
		else {
			header('Location:index.php');
		}

   }

   public function selectId($usu_id, $sala_id) {

		$db = Factory::getDbo();

		$query = $db->getQuery(true);

		$query->select($db->quoteName(array('id','usu_id')));
		$query->from($db->quoteName('#__tabapapo_usu'));
		$query->where($db->quoteName('usu_id').'='.$db->quote($usu_id));
		$query->where($db->quoteName('sala_id').'='.$db->quote($sala_id));

		$db->setQuery($query);

		$results = $db->loadObjectList();

      return $results;

   }
   
   public function updateTime($usu_id, $sala_id) {

      $db = Factory::getDbo();
      
      $id = $this->selectId($usu_id, $sala_id);

      $db = Factory::getDbo();

		$querynow = $db->getQuery(true);

		$querynow->select('now() as now');
		
		$db->setQuery($querynow);
            			
      $resultnow = $db->loadObjectList();

      $object = new stdClass();

      $object->id = $id[0]->id;
      $object->tempo = $resultnow[0]->now;

      $result = $db->updateObject('#__tabapapo_usu', $object, 'id');

      return true;

   }

   public function updateParams($id, $params) {

      $object = new stdClass();

      $object->id = $id;
      $object->params = $params;

      $result = Factory::getDbo()->updateObject('#__tabapapo_usu', $object, 'id');

   }
   
	public function  roomExit($sala_id) {
	   
      $currentuser = Factory::getuser();
      $usu_id = $currentuser->get("id");
         
      if ($usu_id > 0) {
   		try {      
      
            $db = Factory::getDbo();
            
            $id = $this->selectId($usu_id, $sala_id);

      		$query = $db->getQuery(true);
      		
      		$params = new stdClass();
			$params->usu_name = $currentuser->get("username");
			//$params->talkto_name = $form['talkto_name'];
			$params = json_encode($params);

      		$conditions = array($db->quoteName('id').' = '. $id[0]->id);

      		$query->delete($db->quoteName('#__tabapapo_usu'));
      		$query->where($conditions);

      		$db->setQuery($query);
      		$result = $db->execute();

            $userout = new stdClass();
            $userout->sala_id = $sala_id;
            $userout->privado = 0;
            $userout->falacom_id = 0;
            $userout->params = $params;
            
            $msg = $this->sendMessageSys($userout, 2); //msg type 2 exit
            
         return $sala_id;	

           }
           
   		catch (Exception $e)
   		{
   			$msg = $e->getMessage();
   			Factory::getApplication()->enqueueMessage($msg, 'error'); 
   			$resultmsg = null;
   		  }
           
      	}

	}


	public function deleteUsers($sala_id, $type) {

		try {      
   
			$db = Factory::getDbo();

			$querylist = $db->getQuery(true);

			$querylist->select($db->quoteName(array('id','sala_id','usu_id','status','ip','params','tempo')));
			$querylist->from($db->quoteName('#__tabapapo_usu'));
			
			if ($sala_id) {

				$querylist->where($db->quoteName('sala_id').'='.$db->quote($sala_id));

			}
			
			$querylist->where('timestampdiff(second, tempo, now()) > 30');

			$db->setQuery($querylist);
			$db->execute();

			$num_rows = $db->getNumRows();
			$results = $db->loadObjectList();
         
         if ($num_rows) {
            
            $db = Factory::getDbo();
            
      		$query = $db->getQuery(true);

      		$query->delete($db->quoteName('#__tabapapo_usu'));
      		$query->where('timestampdiff(second, tempo, now()) > 30');

      		$db->setQuery($query);
      		$result = $db->execute();

				if ($type == 'yes-msg') {
            
            	for ($i = 0; $i < $num_rows; $i++) {
            
               	$userout = new stdClass();
               	$userout->sala_id = $sala_id;
               	$userout->privado = 0;
               	$userout->falacom_id = 0;
               	$userout->params = $results[$i]->params;

               	$msgout = $this->sendMessageSys($userout,2);
               
            	}
         	}
         }
         return true;	

        }
        
		catch (Exception $e)
		{
			$msg = $e->getMessage();
			Factory::getApplication()->enqueueMessage($msg, 'error'); 
			$resultmsg = null;
		  }

	}
   
	public function deleteMsgs($sala_id) {
	   
		try {      
   
         $db = Factory::getDbo();
         
   		$query = $db->getQuery(true);

   		$query->delete($db->quoteName('#__tabapapo_msg'));
   		$query->where('timestampdiff(second, tempo, now()) > 300');

   		$db->setQuery($query);
   		$result = $db->execute();

         return true;	

        }
        
		catch (Exception $e)
		{
			$msg = $e->getMessage();
			Factory::getApplication()->enqueueMessage($msg, 'error'); 
			$resultmsg = null;
		  }

	}
	

}
