<?php
/**
 * @package Tabaoca.Component.Tabapapo.Site
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

\defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Associations;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Router\Route;
use Joomla\Registry\Registry;
use Joomla\CMS\Uri\Uri;

$document = Factory::getDocument();

$wa = $document->getWebAssetManager();
$wa->useScript('keepalive')
    ->useScript('form.validate');

$this->ignore_fieldsets = ['details', 'item_associations', 'jmetadata'];
$this->useCoreUI        = true;

$app = Factory::getApplication();
$input = $app->input;
$currentuser = Factory::getuser();

if ( !$currentuser->get("id")){

   $app->enqueueMessage(Text::_('JERROR_ALERTNOAUTHOR'), 'error');
   $app->setHeader('status', 403, true);
   return;

}

if (!empty($this->item->id)) {
	if ( $this->item->created_by != $currentuser->get("id")){

	   $app->enqueueMessage(Text::_('JERROR_ALERTNOAUTHOR'), 'error');
	   $app->setHeader('status', 403, true);
	   return;

	}
}

?>
	
<form action="<?php echo Uri::root() . 'index.php?option=com_tabapapo&view=tabapapo&t_id=' . (int) $this->item->id; ?>"
		method="post" 
		name="adminForm" 
		id="adminForm" 
		aria-label="<?php echo Text::_('COM_TABAPAPO_FORM_TITLE_' . ((int) $this->item->id === 0 ? 'NEW' : 'EDIT'), true); ?>"
		class="form-validate form-vertical">
		
		<div class="taba-bg">
			
			<div class="taba-menu">
				<?php echo LayoutHelper::render('joomla.edit.title_alias', $this); ?>   
			</div>
		
			<div class="taba-principal">
			
				<div class="main-card">
			

					<?php echo HTMLHelper::_('uitab.startTabSet', 'myTab', array('active' => 'details')); ?>

					<?php echo HTMLHelper::_('uitab.addTab', 'myTab', 'details', 
						empty($this->item->id) ? Text::_('COM_TABAPAPO_TAB_NEW_CHAT') : Text::_('COM_TABAPAPO_TAB_EDIT_CHAT')); ?>

					<div class="row">
						<div class="col-lg-6">
							<div class="taba-filter">
								<fieldset class="adminform">
										<legend><?php echo $this->form->getLabel('description'); ?></legend>
										<?php echo $this->form->getInput('description'); ?>
								</fieldset>
							</div>
						</div>
						<div class="col-lg-6">
							<div class="taba-filter">	
								<?php echo LayoutHelper::render('joomla.edit.global', $this); ?>
							</div>
						</div>
					</div>
					<?php echo HTMLHelper::_('uitab.endTab'); ?>

					<?php echo HTMLHelper::_('uitab.addTab', 'myTab', 'params', Text::_('COM_TABAPAPO_TAB_DISPLAY')); ?>
					<div class="row">
						<div class="col-md-6">
							<div class="taba-filter">	
								<?php echo LayoutHelper::render('joomla.edit.params', $this); ?>
							</div>
						</div>
					</div>
					<?php echo HTMLHelper::_('uitab.endTab'); ?>

					<?php echo HTMLHelper::_('uitab.addTab', 'myTab', 'publishing', Text::_('COM_TABAPAPO_TAB_PUBLISHING')); ?>
					<div class="row">
						<div class="col-md-6">
							<div class="taba-filter">	
								<legend><?php echo Text::_('COM_TABAPAPO_TAB_PUBLISHING'); ?></legend>
								<?php echo LayoutHelper::render('joomla.edit.publishingdata', $this); ?>
							</div>
						</div>
						<div class="col-md-6">
							<div class="taba-filter">
								<legend><?php echo Text::_('COM_TABAPAPO_METADATA_OPTIONS'); ?></legend>
								<div>
									<?php echo LayoutHelper::render('joomla.edit.metadata', $this); ?>
								</div>
							</div>
						</div>
					</div>
					<?php echo HTMLHelper::_('uitab.endTab'); ?>

					<?php echo HTMLHelper::_('uitab.endTabSet'); ?>

					<input type="hidden" name="task" value="" />
					<input type="hidden" name="forcedLanguage" value="<?php echo $input->get('forcedLanguage', '', 'cmd'); ?>">
					
					<?php echo HTMLHelper::_('form.token'); ?>
				
					<div class="taba-principal">
						<button type="button" class="btn btn-primary" onclick="Joomla.submitbutton('tabapapo.save')">
							<span class="icon-check" aria-hidden="true"></span>
							<?php echo Text::_('JSAVE'); ?>
						</button>
						<button type="button" class="btn btn-danger" onclick="Joomla.submitbutton('tabapapo.cancel')">
							<span class="icon-times" aria-hidden="true"></span>
							<?php echo Text::_('JCANCEL'); ?>
						</button>
					</div>
				</div>
			</div>
		</div>
</form>

<p style="text-align:right;" ><?php echo Text::_('COM_TABAPAPO_POWERED');?><a href="https://tabaoca.org">Tabaoca</a></p>
