<?php
/**
 * @package Tabaoca.Component.Tabapapo.Site
 * @subpackage com_tabapapo
 * @copyright (C) 2023 Jonatas C. Ferreira
 * @license GNU/AGPL v3 (see licence.txt)
 */

\defined('_JEXEC') or die('Restricted access');

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\Session\Session;
use Joomla\CMS\Component\ComponentHelper;

$currentuser = Factory::getuser();
$document = Factory::getDocument();
$app = Factory::getApplication();

$config = $app->getParams('com_tabapapo');
$cb_integration = $config->get('cb_integration');

if ($cb_integration && ComponentHelper::isEnabled('com_comprofiler')) {

	$profile = true;

} else {

	$profile = false;

}

$wa = $document->getWebAssetManager();
$wa->useScript('keepalive');

$users_limit = '';

if (!$currentuser->get("id")){

   $app->enqueueMessage(Text::_('JERROR_ALERTNOAUTHOR'), 'error');
   $app->setHeader('status', 403, true);
   return;

}

if (!$this->item->id){
 
   $app->enqueueMessage(Text::_('COM_TABAPAPO_CHATROOM_ERROR'), 'error');
   $app->setHeader('status', 403, true);
   return;

}

if ($this->item->params->get("users_limit") == '') {
	
	$users_limit = 10; //app->get('users_limit'); global
	
} else {
	
	$users_limit = $this->item->params->get("users_limit");
	
}

if ($this->item->users_on >= $users_limit){

   $app->enqueueMessage(Text::_('COM_TABAPAPO_CHATROOM_CROWDED'), 'error');
   $app->setHeader('status', 403, true);
   return;

}

?>

<script language="JavaScript">

	function addLoadEvent(func) {
		var oldonload = window.onload;
		if (typeof window.onload != 'function') {
				window.onload = func;
		} 
		else {
				window.onload = function() {
						if (oldonload) {
								oldonload();
						}
						func();
				}
			}
	}

	addLoadEvent(function(){setup_tabapapo();});

</script>

<form action="#"
			method="post"
			id="tabapapo_form"
			name="tabapapo_form"
			enctype="multipart/form-data"
			autocomplete="off">


	<div class="taba-menu">

		<span class="taba-title">
			<i class="icon-comments-2"></i><b><?php echo ' ' . $this->item->title; ?></b>
		</span>
		<span class="taba-small">
			<?php if ($this->item->category and $this->item->params->get('show_category')) {
				echo '('.Text::_('JCATEGORY').': '. $this->item->category.')'; }?>
		</span>

		<div class="taba-icon-close taba-icon-chat taba-hover" onclick="exit_room();">
			<i class="icon-unpublish" title="<?php echo Text::_('COM_TABAPAPO_EXIT');?>"></i>
		</div>

	</div>
	<div class="taba-bg">

		<div class="row">
			<div class="col-md-4">
				<div class="taba-filter">
					<div id="showusers" class="taba-frameusers">
					</div>
				</div>
			</div>
				
			<div class="col-md-8">
				<div class="taba-filter">
											
					<div id="showmsg" class="taba-framechat" >
					</div>
					
					<div class="taba-options">
						<div id="statusb" class="taba-status-on taba-status-chat"></div>
						<span id="frase_sys"></span>
						<span class="taba-hover icon-info-2 taba-icon-chat" title="<?php echo Text::_('COM_TABAPAPO_INFORMATION');?>" onclick="show_info('divinfo');"></span>
						<span class="taba-hover icon-smiley-2 taba-icon-chat" title="<?php echo Text::_('COM_TABAPAPO_EMOJIS');?>" onclick="show_info('divemojis');"></span>
						<?php if ($this->item->params->get('show_dice')) {
								echo '<span class="taba-hover icon-cube taba-icon-chat" title="'.Text::_('COM_TABAPAPO_DICE').'" onclick="show_info('."'".'divdice'."'".');"></span>'; }?>             
					</div>

					<div class="taba-options">
						<div class="row">
							<div class="col-md-11">
								<span>
								<input type="text" id="jform_msg" name="jform[msg]" class="taba-message" value=""></span>
							</div>
							<div class="col-md-1">
								<span id="botenviar"></span>
							</div>
						</div>
					</div>
					
					<div class="taba-options">
						<div class="row">
							<div class="col-md-3">
								<input class="form-check-input" type="checkbox" id="jform_status" name="jform[status]" value="0">
								<label for="jform_status"><?php echo Text::_('COM_TABAPAPO_FIELD_AWAY_LABEL');?></label>
							</div>
						
							<div id="cb_private" class="col-md-3" hidden>
								<input class="form-check-input" type="checkbox" id="jform_privado" name="jform[privado]" value="0">
								<label for="jform_privado"><?php echo Text::_('COM_TABAPAPO_FIELD_PRIVATE_LABEL');?></label>
							</div>
							<div class="col-md-3"></div>
							<div class="col-md-3">
								<input class="form-check-input" type="checkbox" id="jform_roll_frame" name="jform[roll_frame]" checked>
								<label for="jform_roll_frame"><?php echo Text::_('COM_TABAPAPO_FIELD_ROLL_LABEL');?></label>
							</div>
						</div>
					</div>

					<div id="divdice" hidden="true" class="taba-dice">
						<div class="taba-info">
							<table>
								<tr>
									<td class="taba-hover" onclick="roll_dice(4);"><img src="<?php echo Route::_('media/com_tabapapo/images/d4.png'); ?>" alt="D4" width="50" height="50"></td>
									<td class="taba-hover" onclick="roll_dice(6);"><img src="<?php echo Route::_('media/com_tabapapo/images/d6.png'); ?>" alt="D6" width="50" height="50"></td>
									<td class="taba-hover" onclick="roll_dice(8);"><img src="<?php echo Route::_('media/com_tabapapo/images/d8.png'); ?>" alt="D8" width="50" height="50"></td>
									<td class="taba-hover" onclick="roll_dice(10);"><img src="<?php echo Route::_('media/com_tabapapo/images/d10.png'); ?>" alt="D10" width="50" height="50"></td>
									<td class="taba-hover" onclick="roll_dice(12);"><img src="<?php echo Route::_('media/com_tabapapo/images/d12.png'); ?>" alt="D12" width="50" height="50"></td>
									<td class="taba-hover" onclick="roll_dice(20);"><img src="<?php echo Route::_('media/com_tabapapo/images/d20.png'); ?>" alt="D20" width="50" height="50"></td>
								</tr>
							</table>
						</div>
					</div>
							
					<div id="divemojis" hidden="true" class="taba-emoji">
						<div class="taba-info">
							<table>
								<tr>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128512');">&#128512</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128518');">&#128518</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128521');">&#128521</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128525');">&#128525</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128526');">&#128526</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128533');">&#128533</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128534');">&#128534</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128535');">&#128535</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128536');">&#128536</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128537');">&#128537</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128540');">&#128540</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128541');">&#128541</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127775');">&#127775</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127774');">&#127774</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127771');">&#127771</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127794');">&#127794</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127796');">&#127796</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127797');">&#127797</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127800');">&#127800</td>
								</tr>
								<tr>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127799');">&#127799</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127801');">&#127801</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127803');">&#127803</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127814');">&#127814</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127817');">&#127817</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127818');">&#127818</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127820');">&#127820</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127821');">&#127821</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127822');">&#127822</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127823');">&#127823</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127824');">&#127824</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127825');">&#127825</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127826');">&#127826</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127827');">&#127827</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#127828');">&#127828</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128004');">&#128004</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128007');">&#128007</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128010');">&#128010</td>
									<td class="taba-hover" onclick="insert_emoji_chat('&#128011');">&#128011</td>
								</tr>
							</table>
						</div>
					</div>
							
					<div id="divinfo" class="row" hidden="true">
						
						<div id="divdesc" class="col-md-6" hidden="true">
							<div class="taba-principal">
								<b><?php echo Text::_('COM_TABAPAPO_DESCRIPTION');?></b>
								<div class="taba-info"><p><?php echo $this->item->description; ?></p></div>
							</div>
						</div>
						
						<div class="col-md-6">
							<div class="taba-principal">
								<b><?php echo Text::_('COM_TABAPAPO_INFORMATION');?></b>
								<div class="taba-info">
									<ul>
										<li><?php echo Text::_('COM_TABAPAPO_INFORMATION_1');?></li>
										<li><?php echo Text::_('COM_TABAPAPO_INFORMATION_2');?></li>
										<li><?php echo Text::_('COM_TABAPAPO_INFORMATION_3');?></li>
									</ul>
								</div>
							</div>
						</div>

					</div>

				</div>		  
			</div>
		</div>
		<?php

			if ($this->item->params->get('show_private')) { $show_private = '1';} else { $show_private = '0'; }
			
			echo HTMLHelper::_('form.token');

		?>

		<input type="hidden" id="jform_sala_id" name="jform[sala_id]" value="<?php echo $this->item->id; ?>">
		<input type="hidden" id="jform_usu_id" name="jform[usu_id]" value="<?php echo $currentuser->get("id"); ?>">
		<input type="hidden" id="jform_talkto_id" name="jform[talkto_id]" value="0">
		<input type="hidden" id="jform_talkto_name" name="jform[talkto_name]" value="">
		<input type="hidden" id="jform_owner" name="jform[owner]" value="<?php echo $this->item->created_by; ?>">
		<input type="hidden" id="jform_description" name="jform[description]" value="<?php echo $this->item->description; ?>">
		<input type="hidden" id="jform_show_info" name="jform[show_info]" value="0">
		<input type="hidden" id="jform_show_private" name="jform[show_private]" value="<?php echo $show_private; ?>">
		<input type="hidden" id="jform_users_limit" name="jform[users_limit]" value="<?php echo $users_limit; ?>">
		<input type="hidden" id="jform_tk" name="jform[tk]" value="<?php echo Session::getFormToken(); ?>">

		<input type="hidden" id="uri_tabapapo" value="<?php echo Uri::root(); ?>">

		<input type="hidden" id="taba_profile" value="<?php echo $profile; ?>">

	</div>
</form>
<p style="text-align:right;" ><?php echo Text::_('COM_TABAPAPO_POWERED');?><a href="https://tabaoca.org">Tabaoca</a></p>
